@@ -35,18 +35,6 @@ func TestClient(t *testing.T) {
 			domain:  "name.io",
 			wantErr: false,
 		},
-		{
-			domain:  "name.red",
-			wantErr: false,
-		},
-		{
-			domain:  "name.green",
-			wantErr: false,
-		},
-		{
-			domain:  "color.black",
-			wantErr: false,
-		},
 		{
 			domain:  "name.cn",
 			wantErr: false,
@@ -99,6 +87,10 @@ func TestClient(t *testing.T) {
 			domain:  "nic.mx",
 			wantErr: false,
 		},
+		{
+			domain:  "google.ro",
+			wantErr: false,
+		},
 	}
 	client := NewClient().WithReferralCache(true)
 	for _, scenario := range scenarios {
